@@ -1,19 +1,19 @@
-/* GNU mailutils - a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
+/* GNU Mailutils -- a suite of utilities for electronic mail
+   Copyright (C) 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, or (at your option)
    any later version.
 
-   This program is distributed in the hope that it will be useful,
+   GNU Mailutils is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   along with GNU Mailutils; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
 
 #if defined(HAVE_CONFIG_H)
 # include <config.h>
@@ -25,6 +25,7 @@
 #include <unistd.h>
 #include <errno.h>
 #include <string.h>  /* strerror(3), strdup(3) */
+#include <getline.h>
 
 #include <mailutils/errno.h>
 #include <mailutils/mailbox.h>
@@ -35,11 +36,16 @@
 #include <mailutils/error.h>
 #include <mailutils/address.h>
 #include <mailutils/registrar.h>
+#include <mailutils/stream.h>
+#include <mailutils/guile.h>
+#include <mailutils/nls.h>
+#include <mailutils/argp.h>
+#include <mailutils/list.h>
+#include <mailutils/mutil.h>
+#include <mailutils/attribute.h>
+#include <mailutils/envelope.h>
 #include <mu_asprintf.h>
 
-#include <libguile.h>
-#include <mu_scm.h>
-
 extern char *program_file;
 extern char *program_expr;
 extern char *user_name;
