@@ -1,59 +1,62 @@
-/* GNU mailutils - a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001 Free Software Foundation, Inc.
+/* GNU Mailutils -- a suite of utilities for electronic mail
+   Copyright (C) 1999, 2001, 2002, 2003 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, or (at your option)
    any later version.
 
-   This program is distributed in the hope that it will be useful,
+   GNU Mailutils is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   along with GNU Mailutils; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
 
 #include "imap4d.h"
 
-FILE *ifile;
-FILE *ofile;
 mailbox_t mbox;
 char *homedir;
 int state = STATE_NONAUTH;
 int debug_mode = 0;
-struct mu_auth_data *auth_data; 
+struct mu_auth_data *auth_data;
 
 struct daemon_param daemon_param = {
-  MODE_INTERACTIVE,     /* Start in interactive (inetd) mode */
-  20,                   /* Default maximum number of children */
-  143,                  /* Standard IMAP4 port */
-  1800,                 /* RFC2060: 30 minutes. */
-  0                     /* No transcript by default */
+  MODE_INTERACTIVE,		/* Start in interactive (inetd) mode */
+  20,				/* Default maximum number of children */
+  143,				/* Standard IMAP4 port */
+  1800,				/* RFC2060: 30 minutes. */
+  0				/* No transcript by default */
 };
 
+int login_disabled;
+
 /* Number of child processes.  */
 volatile size_t children;
 
-const char *argp_program_version = "imap4d (" PACKAGE_STRING ")";
-static char doc[] = "GNU imap4d -- the IMAP4D daemon";
+const char *program_version = "imap4d (" PACKAGE_STRING ")";
+static char doc[] = N_("GNU imap4d -- the IMAP4D daemon");
 
-static struct argp_option options[] = 
-{
-  {"other-namespace", 'O', "PATHLIST", 0,
-   "set the `other' namespace", 0},
-  {"shared-namespace", 'S', "PATHLIST", 0,
-   "set the `shared' namespace", 0},
-  { NULL,      0, NULL, 0, NULL, 0 }
+#define ARG_LOGIN_DISABLED 1
+static struct argp_option options[] = {
+  {"other-namespace", 'O', N_("PATHLIST"), 0,
+   N_("set the `other' namespace"), 0},
+  {"shared-namespace", 'S', N_("PATHLIST"), 0,
+   N_("set the `shared' namespace"), 0},
+  {"login-disabled", ARG_LOGIN_DISABLED, NULL, 0,
+   N_("Disable LOGIN command")},
+  {NULL, 0, NULL, 0, NULL, 0}
 };
 
-static error_t imap4d_parse_opt (int key, char *arg, struct argp_state *state);
+static error_t imap4d_parse_opt (int key, char *arg,
+				 struct argp_state *state);
 
 static struct argp argp = {
   options,
   imap4d_parse_opt,
-  NULL, 
+  NULL,
   doc,
   NULL,
   NULL, NULL
@@ -62,6 +65,12 @@ static struct argp argp = {
 static const char *imap4d_capa[] = {
   "daemon",
   "auth",
+#ifdef WITH_TLS
+  "tls",
+#endif /* WITH_TLS */
+#ifdef WITH_GSASL
+  "gsasl",
+#endif
   "common",
   "mailbox",
   "logging",
@@ -69,10 +78,9 @@ static const char *imap4d_capa[] = {
   NULL
 };
 
-static int imap4d_mainloop      __P ((int, int));
-static void imap4d_daemon_init  __P ((void));
-static void imap4d_daemon       __P ((unsigned int, unsigned int));
-static int imap4d_mainloop      __P ((int, int));
+static void imap4d_daemon_init __P ((void));
+static void imap4d_daemon __P ((unsigned int, unsigned int));
+static int imap4d_mainloop __P ((int, FILE *, FILE *));
 
 static error_t
 imap4d_parse_opt (int key, char *arg, struct argp_state *state)
@@ -82,14 +90,19 @@ imap4d_parse_opt (int key, char *arg, struct argp_state *state)
     case ARGP_KEY_INIT:
       state->child_inputs[0] = state->input;
       break;
-      
+
     case 'O':
       set_namespace (NS_OTHER, arg);
       break;
-      
+
     case 'S':
       set_namespace (NS_SHARED, arg);
       break;
+
+    case ARG_LOGIN_DISABLED:
+      login_disabled = 1;
+      imap4d_capability_add ("LOGINDISABLED");
+      break;
       
     default:
       return ARGP_ERR_UNKNOWN;
@@ -102,12 +115,27 @@ main (int argc, char **argv)
 {
   struct group *gr;
   int status = EXIT_SUCCESS;
- 
-  state = STATE_NONAUTH; /* Starting state in non-auth.  */
 
-  MU_AUTH_REGISTER_ALL_MODULES();
+  /* Native Language Support */
+  mu_init_nls ();
+
+  state = STATE_NONAUTH;	/* Starting state in non-auth.  */
+
+  MU_AUTH_REGISTER_ALL_MODULES ();
+  imap4d_capability_init ();
+
+  mu_argp_init (program_version, NULL);
+#ifdef WITH_TLS
+  mu_tls_init_argp ();
+#endif /* WITH_TLS */
+#ifdef WITH_GSASL
+  mu_gsasl_init_argp ();
+#endif
   mu_argp_parse (&argp, &argc, &argv, 0, imap4d_capa, NULL, &daemon_param);
 
+  auth_gssapi_init ();
+  auth_gsasl_init ();
+  
 #ifdef USE_LIBPAM
   if (!pam_service)
     pam_service = "gnu-imap4d";
@@ -125,13 +153,13 @@ main (int argc, char **argv)
       gr = getgrnam ("mail");
       if (gr == NULL)
 	{
-	  perror ("Error getting mail group");
+	  perror (_("Error getting mail group"));
 	  exit (1);
 	}
-      
+
       if (setgid (gr->gr_gid) == -1)
 	{
-	  perror ("Error setting mail group");
+	  perror (_("Error setting mail group"));
 	  exit (1);
 	}
     }
@@ -140,7 +168,7 @@ main (int argc, char **argv)
   {
     list_t bookie;
     registrar_get_list (&bookie);
-    list_append (bookie, mbox_record); 
+    list_append (bookie, mbox_record);
     list_append (bookie, path_record);
   }
 
@@ -171,15 +199,20 @@ main (int argc, char **argv)
   /* Redirect any stdout error from the library to syslog, they
      should not go to the client.  */
   mu_error_set_print (mu_syslog_error_printer);
-  
-  umask (S_IROTH | S_IWOTH | S_IXOTH);  /* 007 */
+
+  umask (S_IROTH | S_IWOTH | S_IXOTH);	/* 007 */
+
+  /* Check TLS environment, i.e. cert and key files */
+#ifdef WITH_TLS
+  starttls_init ();
+#endif /* WITH_TLS */
 
   /* Actually run the daemon.  */
   if (daemon_param.mode == MODE_DAEMON)
     imap4d_daemon (daemon_param.maxchildren, daemon_param.port);
   /* exit (0) -- no way out of daemon except a signal.  */
   else
-    status = imap4d_mainloop (fileno (stdin), fileno (stdout));
+    status = imap4d_mainloop (fileno (stdin), stdin, stdout);
 
   /* Close the syslog connection and exit.  */
   closelog ();
@@ -188,21 +221,16 @@ main (int argc, char **argv)
 }
 
 static int
-imap4d_mainloop (int infile, int outfile)
+imap4d_mainloop (int fd, FILE *infile, FILE *outfile)
 {
   char *text;
-  
+
   /* Reset hup to exit.  */
   signal (SIGHUP, imap4d_signal);
   /* Timeout alarm.  */
   signal (SIGALRM, imap4d_signal);
 
-  ifile = fdopen (infile, "r");
-  ofile = fdopen (outfile, "w");
-  if (!ofile || !ifile)
-    imap4d_bye (ERR_NO_OFILE);
-
-  setvbuf(ofile, NULL, _IOLBF, 0);
+  util_setio (infile, outfile);
 
   /* log information on the connecting client */
   if (!debug_mode)
@@ -210,36 +238,35 @@ imap4d_mainloop (int infile, int outfile)
       struct sockaddr_in cs;
       int len = sizeof cs;
 
-      syslog (LOG_INFO, "Incoming connection opened");
-      if (getpeername (infile, (struct sockaddr*)&cs, &len) < 0)
-	syslog (LOG_ERR, "can't obtain IP address of client: %s",
+      syslog (LOG_INFO, _("Incoming connection opened"));
+      if (getpeername (fd, (struct sockaddr *) &cs, &len) < 0)
+	syslog (LOG_ERR, _("can't obtain IP address of client: %s"),
 		strerror (errno));
       else
-	syslog (LOG_INFO, "connect from %s", inet_ntoa(cs.sin_addr));
+	syslog (LOG_INFO, _("connect from %s"), inet_ntoa (cs.sin_addr));
       text = "IMAP4rev1";
     }
   else
     {
-      syslog (LOG_INFO, "Started in debugging mode");
+      syslog (LOG_INFO, _("Started in debugging mode"));
       text = "IMAP4rev1 Debugging mode";
     }
-  
+
   /* Greetings.  */
   util_out (RESP_OK, text);
-  fflush (ofile);
+  util_flush_output ();
 
   while (1)
     {
-      char *cmd = imap4d_readline (ifile);
+      char *cmd = imap4d_readline ();
       /* check for updates */
       imap4d_sync ();
       util_do_command (cmd);
       imap4d_sync ();
       free (cmd);
-      fflush (ofile);
+      util_flush_output ();
     }
 
-  closelog ();
   return EXIT_SUCCESS;
 }
 
@@ -253,7 +280,7 @@ imap4d_daemon_init (void)
      first three one, in, out, err   */
   if (daemon (0, 0) < 0)
     {
-      perror("fork failed:");
+      perror (_("fork failed"));
       exit (1);
     }
 
@@ -286,18 +313,18 @@ imap4d_daemon (unsigned int maxchildren, unsigned int port)
   listenfd = socket (AF_INET, SOCK_STREAM, 0);
   if (listenfd == -1)
     {
-      syslog (LOG_ERR, "socket: %s", strerror(errno));
+      syslog (LOG_ERR, "socket: %s", strerror (errno));
       exit (1);
     }
-  size = 1; /* Use size here to avoid making a new variable.  */
-  setsockopt (listenfd, SOL_SOCKET, SO_REUSEADDR, &size, sizeof(size));
+  size = 1;			/* Use size here to avoid making a new variable.  */
+  setsockopt (listenfd, SOL_SOCKET, SO_REUSEADDR, &size, sizeof (size));
   size = sizeof (server);
   memset (&server, 0, size);
   server.sin_family = AF_INET;
   server.sin_addr.s_addr = htonl (INADDR_ANY);
   server.sin_port = htons (port);
 
-  if (bind (listenfd, (struct sockaddr *)&server, size) == -1)
+  if (bind (listenfd, (struct sockaddr *) &server, size) == -1)
     {
       syslog (LOG_ERR, "bind: %s", strerror (errno));
       exit (1);
@@ -309,43 +336,44 @@ imap4d_daemon (unsigned int maxchildren, unsigned int port)
       exit (1);
     }
 
+  syslog (LOG_INFO, _("GNU imap4d started"));
+
   for (;;)
     {
       if (children > maxchildren)
-        {
-          syslog (LOG_ERR, "too many children (%lu)",
+	{
+	  syslog (LOG_ERR, _("too many children (%lu)"),
 		  (unsigned long) children);
-          pause ();
-          continue;
-        }
-      connfd = accept (listenfd, (struct sockaddr *)&client,
-		       (socklen_t*) &size);
+	  pause ();
+	  continue;
+	}
+      connfd = accept (listenfd, (struct sockaddr *) &client,
+		       (socklen_t *) & size);
       if (connfd == -1)
-        {
-          if (errno == EINTR)
-            continue;
-          syslog (LOG_ERR, "accept: %s", strerror (errno));
-          exit (1);
-        }
+	{
+	  if (errno == EINTR)
+	    continue;
+	  syslog (LOG_ERR, "accept: %s", strerror (errno));
+	  exit (1);
+	}
 
       pid = fork ();
       if (pid == -1)
-        syslog(LOG_ERR, "fork: %s", strerror (errno));
-      else if (pid == 0) /* Child.  */
-        {
-          int status;
-          close (listenfd);
-          status = imap4d_mainloop (connfd, connfd);
-          closelog ();
-          exit (status);
-        }
+	syslog (LOG_ERR, "fork: %s", strerror (errno));
+      else if (pid == 0)	/* Child.  */
+	{
+	  int status;
+	  close (listenfd);
+	  status = imap4d_mainloop (connfd,
+				    fdopen (connfd, "r"),
+				    fdopen (connfd, "w"));
+	  closelog ();
+	  exit (status);
+	}
       else
-        {
-          ++children;
-        }
+	{
+	  ++children;
+	}
       close (connfd);
     }
 }
-
-
-
