@@ -1,19 +1,19 @@
-/* GNU mailutils - a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001 Free Software Foundation, Inc.
+/* GNU Mailutils -- a suite of utilities for electronic mail
+   Copyright (C) 1999, 2001, 2002, 2003 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, or (at your option)
    any later version.
 
-   This program is distributed in the hope that it will be useful,
+   GNU Mailutils is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   along with GNU Mailutils; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
 
 #ifndef _IMAP4D_H
 #define _IMAP4D_H 1
@@ -25,8 +25,9 @@
 #define _QNX_SOURCE
 #define _GNU_SOURCE
 
+#include <sys/types.h>
 #ifdef HAVE_SECURITY_PAM_APPL_H
-#include <security/pam_appl.h>
+# include <security/pam_appl.h>
 #endif
 
 #ifdef HAVE_SHADOW_H
@@ -86,7 +87,10 @@
 #include <mailutils/registrar.h>
 #include <mailutils/stream.h>
 #include <mailutils/mu_auth.h>
+#include <mailutils/iterator.h>
 #include <mailutils/url.h>
+#include <mailutils/tls.h>
+#include <mailutils/nls.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -125,7 +129,8 @@ struct imap4d_command
 #define ERR_NO_OFILE 2
 #define ERR_TIMEOUT 3
 #define ERR_SIGNAL 4
-  
+#define ERR_TLS 5
+
 /* Namespace numbers */
 #define NS_PRIVATE 0
 #define NS_OTHER   1
@@ -138,8 +143,6 @@ struct imap4d_command
 #define WCARD_RECURSE_MATCH  2
        
 extern struct imap4d_command imap4d_command_table[];
-extern FILE *ifile;
-extern FILE *ofile;
 extern mailbox_t mbox;
 extern char *homedir;
 extern char *rootdir;
@@ -148,7 +151,9 @@ extern volatile size_t children;
 extern int is_virtual;
 extern struct daemon_param daemon_param;
 extern struct mu_auth_data *auth_data; 
-	
+
+extern int login_disabled;
+
 #ifndef HAVE_STRTOK_R
 extern char *strtok_r __P((char *s, const char *delim, char **save_ptr));
 #endif
@@ -180,6 +185,10 @@ extern int  imap4d_search0 __P((char *arg, int isuid, char *replybuf, size_t rep
 extern int  imap4d_select __P ((struct imap4d_command *, char *));
 extern int  imap4d_select0 __P ((struct imap4d_command *, char *, int));
 extern int  imap4d_select_status __P((void));
+#ifdef WITH_TLS
+extern int  imap4d_starttls __P ((struct imap4d_command *, char *));
+extern void starttls_init __P((void));
+#endif /* WITH_TLS */
 extern int  imap4d_status __P ((struct imap4d_command *, char *));
 extern int  imap4d_store __P ((struct imap4d_command *, char *));
 extern int  imap4d_store0 __P ((char *, int, char *, size_t));
@@ -188,6 +197,7 @@ extern int  imap4d_uid __P ((struct imap4d_command *, char *));
 extern int  imap4d_unsubscribe __P ((struct imap4d_command *, char *));
 extern int  imap4d_namespace __P ((struct imap4d_command *, char *));
 extern int  imap4d_version __P ((struct imap4d_command *, char *));
+extern int  imap4d_idle __P ((struct imap4d_command *, char *));
   
 /* Shared between fetch and store */  
 extern void fetch_flags0 (const char *prefix, message_t msg, int isuid);
@@ -209,6 +219,10 @@ extern int namespace_init __P((char *path));
 extern char * namespace_getfullpath __P((char *name, const char *delim));
 extern char * namespace_checkfullpath __P((char *name, const char *pattern,
 					   const char *delim));
+/* Capability functions */
+extern void imap4d_capability_add __P((const char *str));
+extern void imap4d_capability_remove __P((const char *str));
+extern void imap4d_capability_init __P((void));
   
 /* Helper functions.  */
 extern int  util_out __P ((int, const char *, ...));
@@ -219,8 +233,8 @@ extern int  util_start __P ((char *));
 extern int  util_finish __P ((struct imap4d_command *, int, const char *, ...));
 extern int  util_getstate __P ((void));
 extern int  util_do_command __P ((char *));
-extern char *imap4d_readline __P ((FILE*));
-extern char *imap4d_readline_ex __P ((FILE*));
+extern char *imap4d_readline __P ((void));
+extern char *imap4d_readline_ex __P ((void));
 extern char *util_getword __P ((char *, char **));
 extern char *util_getitem __P ((char *, const char *, char **));
 extern int  util_token __P ((char *, size_t, char **));
@@ -255,6 +269,45 @@ int util_attribute_to_type __P((const char *item, int *type));
 int util_type_to_attribute __P((int type, char **attr_str));
 int util_attribute_matches_flag __P((attribute_t attr, const char *item));
 int util_uidvalidity __P((mailbox_t smbox, unsigned long *uidvp));
+
+void util_setio __P((FILE*, FILE*));
+void util_flush_output __P((void));
+void util_get_input __P((stream_t *pstr));
+void util_get_output __P((stream_t *pstr));
+void util_set_input __P((stream_t str));
+void util_set_output __P((stream_t str));
+int util_wait_input __P((int));
+  
+void util_register_event __P((int old_state, int new_state,
+			      list_action_t *action, void *data));
+void util_event_remove __P((void *id));
+void util_run_events __P((int old_state, int new_state));
+  
+int util_is_master __P((void));
+void util_bye __P((void));  
+void util_atexit __P((void (*fp) __PMT((void))));
+
+#ifdef WITH_TLS
+int imap4d_init_tls_server __P((void));
+#endif /* WITH_TLS */
+
+typedef int (*imap4d_auth_handler_fp) __PMT((struct imap4d_command *,
+					     char *, char *, char **));
+  
+extern void auth_add __P((char *name, imap4d_auth_handler_fp handler));
+extern void auth_remove __P((char *name));
+
+#ifdef WITH_GSSAPI  
+extern void auth_gssapi_init __P((void));
+#else
+# define auth_gssapi_init()  
+#endif
+
+#ifdef WITH_GSASL
+extern void auth_gsasl_init __P((void));
+#else
+# define auth_gsasl_init()
+#endif
   
 #ifdef __cplusplus
 }
