@@ -115,6 +115,16 @@ extern char * mu_expand_path_pattern __P((const char *pattern,
 
 extern int mu_rfc2822_references __P((message_t msg, char **pstr));
 extern int mu_rfc2822_in_reply_to __P((message_t msg, char **pstr));
+
+/* Find NEEDLE in the HAYSTACK. Case insensitive comparison */
+extern char *mu_strcasestr __P((const char *haystack, const char *needle));
+
+extern int mu_string_unfold __P((char *text, size_t *plen));
+
+extern int munre_set_regex __P((char *str, int caseflag, char **errp));
+extern int munre_subject  __P((const char *subject, const char **new_subject));
+
+extern char *mu_charset_lookup __P((char *lang, char *terr));
   
 #ifdef __cplusplus
 }
