@@ -1,20 +1,19 @@
-/* GNU mailutils - a suite of utilities for electronic mail
+/* GNU Mailutils -- a suite of utilities for electronic mail
    Copyright (C) 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, or (at your option)
    any later version.
 
-   This program is distributed in the hope that it will be useful,
+   GNU Mailutils is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
-
+   along with GNU Mailutils; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -30,6 +29,7 @@
 # include <strings.h>
 #endif
 #include <errno.h>
+#include <mailutils/errno.h>
 #include <mu_dbm.h>
 #include <xalloc.h>
 
@@ -47,8 +47,8 @@ mu_fcheck_perm (int fd, int mode)
     }
   if ((st.st_mode & 0777) != mode)
     {
-      errno = EPERM;
-    return 1;
+      errno = MU_ERR_UNSAFE_PERMS;
+      return 1;
     }
   return 0;
 }
@@ -69,8 +69,8 @@ mu_check_perm (const char *name, int mode)
     }
   if ((st.st_mode & 0777) != mode)
     {
-      errno = EPERM;
-    return 1;
+      errno = MU_ERR_UNSAFE_PERMS;
+      return 1;
     }
   return 0;
 }
@@ -266,7 +266,7 @@ mu_dbm_firstkey (DBM_FILE db)
 
   if (!db->dbc)
     {
-      if (db->db->cursor(db->db, NULL, &db->dbc, 0) != 0)
+      if (db->db->cursor(db->db, NULL, &db->dbc BDB2_CURSOR_LASTARG) != 0)
 	return key;
     }
 
