@@ -19,18 +19,28 @@
 
 (define-module (mailutils))
 
+(define mu-libs (list "libmailbox"
+		      "libmuauth"
+		      "libmu_mbox"
+		      "libmu_mh"
+		      "libmu_pop"
+		      "libmu_imap"))
+
 (let ((lib-path "/home/gray/alpha/lib/"))
-  (dynamic-link (string-append lib-path "libmailbox"))
+  (for-each
+   (lambda (lib)
+	   (dynamic-link (string-append lib-path lib)))
+   mu-libs)
   (cond
    ((or (string=? (version) "1.4")
 	(string=? (version) "1.4.1"))
     (dynamic-call "mu_scm_init"
 		  (dynamic-link (string-append
 				 lib-path
-				 "libguile-mailutils-v-0.3.1"))))
+				 "libguile-mailutils-v-0.4"))))
    (else
     (load-extension (string-append
-		     lib-path "libguile-mailutils-v-0.3.1") "mu_scm_init"))))
+		     lib-path "libguile-mailutils-v-0.4") "mu_scm_init"))))
 
 (export mu-package)
 (export mu-package-string)
