@@ -1,19 +1,19 @@
-/* GNU mailutils - a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
+/* GNU Mailutils -- a suite of utilities for electronic mail
+   Copyright (C) 1999, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, or (at your option)
    any later version.
 
-   This program is distributed in the hope that it will be useful,
+   GNU Mailutils is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   along with GNU Mailutils; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
 
 #include "mail.h"
 
@@ -34,7 +34,7 @@ mail_headers (int argc, char **argv)
   int lines = util_screen_lines ();
   int num;
 
-  if (msgset_parse (argc, argv, &list))
+  if (msgset_parse (argc, argv, MSG_NODELETED|MSG_SILENT, &list))
      return 1;
 
   num = 0;
@@ -52,7 +52,7 @@ mail_headers (int argc, char **argv)
       low = list->msg_part[0] - (lines / 2);
       if (low < 1)
 	low = 1;
-      high = low + lines;
+      high = low + util_screen_lines ();
       if ((unsigned int)high > total)
 	{
 	  high = total;
@@ -60,8 +60,7 @@ mail_headers (int argc, char **argv)
 	}
     }
 
-  for (; low <= high; low++)
-    mail_from0 (low, 0);
+  util_range_msg (low, high, MSG_NODELETED|MSG_SILENT, mail_from0, NULL);
 
   msgset_free (list);
   return 0;
