@@ -24,14 +24,16 @@ size_t total;
 FILE *ofile;
 int interactive;
 
+static list_t command_list;
+
 const char *program_version = "mail (" PACKAGE_STRING ")";
 static char doc[] = N_("GNU mail -- the standard /bin/mail interface");
 static char args_doc[] = N_("[address...]");
 
 static struct argp_option options[] = {
   {"exist",   'e', 0,      0, N_("Return true if mail exists"), 0},
-  {"file",    'f', N_("FILE"), OPTION_ARG_OPTIONAL,
-			          N_("Operate on mailbox FILE (default ~/mbox)"), 0},
+  {"file",    'f', N_("URL"), OPTION_ARG_OPTIONAL,
+			      N_("Operate on given mailbox URL (default ~/mbox)"), 0},
   {"byname",  'F', 0,      0, N_("Save messages according to sender"), 0},
   {"headers", 'H', 0,      0, N_("Write a header summary and exit"), 0},
   {"ignore",  'i', 0,      0, N_("Ignore interrupts"), 0},
@@ -43,11 +45,7 @@ static struct argp_option options[] = {
   {"subject", 's', N_("SUBJ"), 0, N_("Send a message with a Subject of SUBJ"), 0},
   {"to",      't', 0,      0, N_("Precede message by a list of addresses"), 0},
   {"user",    'u', N_("USER"), 0, N_("Operate on USER's mailbox"), 0},
-  {NULL,      0,  NULL,    OPTION_DOC,
-   N_("Note: Argument to --file (-f) option is optional. If it is present, "
-   "it must follow the short option immediately, without any intervening "
-   "whitespace. If it is used with the long option, it must be separated "
-   "from it by an equal sign, with no intervening whitespace."), 0},
+
   { NULL,      0, NULL, 0, NULL, 0 }
 };
 
@@ -67,7 +65,7 @@ parse_opt (int key, char *arg, struct argp_state *state)
   switch (key)
     {
     case 'e':
-      util_do_command ("set mode=exist");
+      util_cache_command (&command_list, "set mode=exist");
       break;
       
     case 'f':
@@ -86,23 +84,23 @@ parse_opt (int key, char *arg, struct argp_state *state)
       
     case 'p':
     case 'r':
-      util_do_command ("set mode=print");
+      util_cache_command (&command_list, "set mode=print");
       break;
       
     case 'q':
-      util_do_command ("set quit");
+      util_cache_command (&command_list, "set quit");
       break;
       
     case 't':
-      util_do_command ("set mode=send");
+      util_cache_command (&command_list, "set mode=send");
       break;
       
     case 'H':
-      util_do_command ("set mode=headers");
+      util_cache_command (&command_list, "set mode=headers");
       break;
       
     case 'i':
-      util_do_command ("set ignore");
+      util_cache_command (&command_list, "set ignore");
       break;
       
     case 'n':
@@ -110,13 +108,13 @@ parse_opt (int key, char *arg, struct argp_state *state)
       break;
       
     case 'N':
-      util_do_command ("set noheader");
+      util_cache_command (&command_list, "set noheader");
       break;
       
     case 's':
-      util_do_command ("set mode=send");
-      util_do_command ("set noasksub");
-      util_do_command ("set subject=\"%s\"", arg);
+      util_cache_command (&command_list, "set mode=send");
+      util_cache_command (&command_list, "set noasksub");
+      util_cache_command (&command_list, "set subject=\"%s\"", arg);
       break;
       
     case 'u':
@@ -124,9 +122,9 @@ parse_opt (int key, char *arg, struct argp_state *state)
       break;
       
     case 'F':
-      util_do_command ("set byname");
+      util_cache_command (&command_list, "set byname");
       break;
-      
+
     case ARGP_KEY_ARG:
       /* People often tend to separate -f option from its argument
 	 with a whitespace. This heuristics tries to catch the
@@ -134,10 +132,6 @@ parse_opt (int key, char *arg, struct argp_state *state)
 
       if (args->file)
 	{
-	  util_error (_("Usage error: --file takes an optional argument, "
-	              "it must follow the option\n"
-	              "without any intervening whitespace."));
-	  util_error (_("Run mail --help for more info."));
 	  args->file = arg;
 	}
       else
@@ -146,7 +140,7 @@ parse_opt (int key, char *arg, struct argp_state *state)
 				sizeof (char *) * (state->arg_num + 2));
 	  args->args[state->arg_num] = arg;
 	  args->args[state->arg_num + 1] = NULL;
-	  util_do_command ("set mode=send");
+	  util_cache_command (&command_list, "set mode=send");
 	}
       break;
       
@@ -169,6 +163,9 @@ static const char *mail_capa[] = {
 	"common",
 	"license",
 	"mailbox",
+#ifdef WITH_TLS
+	"tls",
+#endif
 	 NULL 
 };
 			     
@@ -220,7 +217,7 @@ main (int argc, char **argv)
   /* Native Language Support */
   mu_init_nls ();
 
-  /* Register the desire formats.  */
+  /* Register the desired formats.  */
   {
     list_t bookie;
     registrar_get_list (&bookie);
@@ -250,7 +247,7 @@ main (int argc, char **argv)
   /* set up the default environment */
   if (!getenv ("HOME"))
     {
-      char *p = util_get_homedir();
+      char *p = util_get_homedir ();
       setenv ("HOME", p, 0);
     }
   setenv ("DEAD", util_fullpath("~/dead.letter"), 0);
@@ -303,6 +300,13 @@ main (int argc, char **argv)
   util_do_command ("set toplines=5");
   util_do_command ("set autoinc");
   util_do_command ("set regex");
+  util_do_command ("set replyprefix=\"Re: \"");
+  util_do_command ("set charset=auto");
+  util_do_command ("unfold subject");
+  /* Start in mail reading mode */
+  util_do_command ("set mode=read");
+  util_do_command ("set noquit");
+  util_do_command ("set rc");
   
   /* Set the default mailer to sendmail.  */
   {
@@ -312,11 +316,6 @@ main (int argc, char **argv)
     util_setenv ("sendmail", mailer_name, Mail_env_string, 1);
   }
 
-  /* GNU extensions to the environment, for sparky's sanity */
-  util_do_command ("set mode=read");
-  util_do_command ("set nobyname");
-  util_do_command ("set rc");
-  util_do_command ("set noquit");
 
   args.args = NULL;
   args.file = NULL;
@@ -325,12 +324,18 @@ main (int argc, char **argv)
   /* argument parsing */
 
   mu_argp_init (program_version, NULL);
+#ifdef WITH_TLS
+  mu_tls_init_client_argp ();
+#endif
   mu_argp_parse (&argp, &argc, &argv, 0, mail_capa, NULL, &args);
 
   /* read system-wide mail.rc and user's .mailrc */
   if (util_getenv (NULL, "rc", Mail_env_boolean, 0) == 0)
     util_do_command ("source %s", SITE_MAIL_RC);
   util_do_command ("source %s", getenv ("MAILRC"));
+
+  util_run_cached_commands (&command_list);
+  
   if (!interactive)
     {
       util_do_command ("set nocrt");
@@ -355,11 +360,13 @@ main (int argc, char **argv)
       /* FIXME: set cmd to "mail [add1...]" */
       char *buf = NULL;
       int num = 0;
+      int rc;
       if (args.args != NULL)
 	while (args.args[num] != NULL)
 	  num++;
       argcv_string (num, args.args, &buf);
-      return util_do_command ("mail %s", buf);
+      rc = util_do_command ("mail %s", buf);
+      return util_getenv (NULL, "mailx", Mail_env_boolean, 0) ? rc : 0;
     }
   /* Or acting as a normal reader */
   else
@@ -405,6 +412,7 @@ main (int argc, char **argv)
 	  mailbox_get_url (mbox, &url);
 	  util_error (_("Can not open mailbox %s: %s"),
 		      url_to_string (url), mu_strerror (rc));
+	  mailbox_destroy (&mbox);
 	  exit (EXIT_FAILURE);
 	}
 
