@@ -1,19 +1,19 @@
-/* GNU mailutils - a suite of utilities for electronic mail
+/* GNU Mailutils -- a suite of utilities for electronic mail
    Copyright (C) 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, or (at your option)
    any later version.
 
-   This program is distributed in the hope that it will be useful,
+   GNU Mailutils is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   along with GNU Mailutils; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
 
 #ifndef _MAIL_H
 #define _MAIL_H 1
@@ -54,8 +54,8 @@
 #include <xalloc.h>
 
 #ifdef HAVE_READLINE_READLINE_H
-#include <readline/readline.h>
-#include <readline/history.h>
+# include <readline/readline.h>
+# include <readline/history.h>
 #endif
 
 #include <mailutils/address.h>
@@ -64,6 +64,7 @@
 #include <mailutils/body.h>
 #include <mailutils/debug.h>
 #include <mailutils/errno.h>
+#include <mailutils/error.h>
 #include <mailutils/envelope.h>
 #include <mailutils/filter.h>
 #include <mailutils/header.h>
@@ -76,7 +77,8 @@
 #include <mailutils/registrar.h>
 #include <mailutils/stream.h>
 #include <mailutils/url.h>
-
+#include <mailutils/nls.h>
+#include <mailutils/tls.h>
 #include <mailutils/argcv.h>
 #include <getline.h>
 #include <mu_asprintf.h>
@@ -138,16 +140,17 @@ typedef struct message_set msgset_t;
 
 struct message_set
 {
-  msgset_t *next;        /* Link to the next message set */
-  unsigned int npart;    /* Number of parts in this set */
-  unsigned int *msg_part;/* Array of part numbers: msg_part[0] is the message
-			    number */
+  msgset_t *next;       /* Link to the next message set */
+  unsigned int npart;   /* Number of parts in this set */
+  size_t *msg_part;     /* Array of part numbers: msg_part[0] is the 
+                           message number */
 };
 
+typedef int (*msg_handler_t) __P((msgset_t *mp, message_t mesg, void *data));
+
 /* Global variables and constants*/
 extern mailbox_t mbox;
 extern unsigned int cursor;
-extern unsigned int realcursor;
 extern size_t total;
 extern FILE *ofile;
 extern int interactive;
@@ -172,7 +175,7 @@ extern int mail_file __P ((int argc, char **argv));
 extern int mail_folders __P ((int argc, char **argv));
 extern int mail_followup __P ((int argc, char **argv));
 extern int mail_from __P ((int argc, char **argv));
-extern int mail_from0 __P((int msgno, int verbose));
+extern int mail_from0 __P((msgset_t *mspec, message_t msg, void *data));
 extern int mail_headers __P ((int argc, char **argv));
 extern int mail_hold __P ((int argc, char **argv));
 extern int mail_help __P ((int argc, char **argv));
@@ -182,6 +185,7 @@ extern int mail_list __P ((int argc, char **argv));
 extern int mail_send __P ((int argc, char **argv));	/* command mail */
 extern int mail_mbox __P ((int argc, char **argv));
 extern int mail_next __P ((int argc, char **argv));
+extern int mail_nounfold __P((int argc, char **argv));
 extern int mail_pipe __P ((int argc, char **argv));
 extern int mail_previous __P ((int argc, char **argv));
 extern int mail_print __P ((int argc, char **argv));
@@ -191,6 +195,7 @@ extern int mail_retain __P ((int argc, char **argv));
 extern int mail_save __P ((int argc, char **argv));
 extern int mail_set __P ((int argc, char **argv));
 extern int mail_shell __P ((int argc, char **argv));
+extern int mail_execute __P((int shell, int argc, char **argv));
 extern int mail_size __P ((int argc, char **argv));
 extern int mail_source __P ((int argc, char **argv));
 extern int mail_summary __P ((int argc, char **argv));
@@ -199,6 +204,7 @@ extern int mail_top __P ((int argc, char **argv));
 extern int mail_touch __P ((int argc, char **argv));
 extern int mail_unalias __P ((int argc, char **argv));
 extern int mail_undelete __P ((int argc, char **argv));
+extern int mail_unfold __P((int argc, char **argv));
 extern int mail_unset __P ((int argc, char **argv));
 extern int mail_version __P ((int argc, char **argv));
 extern int mail_visual __P ((int argc, char **argv));
@@ -222,6 +228,7 @@ extern int mail_is_my_name __P ((char *name));
 extern void mail_set_my_name __P ((char *name));
 extern char *mail_whoami __P ((void));
 extern int mail_header_is_visible __P ((char *str));
+extern int mail_header_is_unfoldable __P((char *str));
 extern int mail_mbox_close __P ((void));
 extern char *mail_expand_name __P((const char *name));
 
@@ -253,15 +260,19 @@ extern msgset_t *msgset_append __P ((msgset_t *one, msgset_t *two));
 extern msgset_t *msgset_range __P ((int low, int high));
 extern msgset_t *msgset_expand __P ((msgset_t *set, msgset_t *expand_by));
 extern msgset_t *msgset_dup __P ((const msgset_t *set));
-extern int msgset_parse __P ((const int argc, char **argv, msgset_t **mset));
+extern int msgset_parse __P ((const int argc, char **argv,
+			      int flags, msgset_t **mset));
 extern int msgset_member __P ((msgset_t *set, size_t n));
 extern msgset_t *msgset_negate __P((msgset_t *set));
+extern size_t msgset_count __P((msgset_t *set));
 
 extern int util_do_command __P ((const char *cmd, ...));
-extern int util_msglist_command __P ((function_t *func, int argc, char **argv, int set_cursor));
-extern int util_msglist_esccmd
-__P ((int (*escfunc) __P ((int, char **, compose_env_t *)),
-      int argc, char **argv, compose_env_t *env, int set_cursor));
+
+extern int util_foreach_msg __P((int argc, char **argv, int flags,
+				 msg_handler_t func, void *data));
+extern int util_range_msg __P((size_t low, size_t high, int flags, 
+			       msg_handler_t func, void *data));
+
 extern function_t* util_command_get __P ((const char *cmd));
 extern char *util_stripwhite __P ((char *string));
 extern struct mail_command_entry util_find_entry __P ((const struct mail_command_entry *table, const char *cmd));
@@ -278,7 +289,7 @@ extern int util_getenv __P ((void *ptr, const char *variable,
 extern int util_printenv __P ((int set));
 extern int util_setenv __P ((const char *name, void *value,
 			     mail_env_data_t type, int overwrite));
-extern int util_isdeleted __P ((message_t msg));
+extern int util_isdeleted __P ((size_t msgno));
 extern char *util_get_homedir __P ((void));
 extern char *util_fullpath __P ((const char *inpath));
 extern char *util_folder_path __P((const char *name));
@@ -287,6 +298,7 @@ extern char *util_get_sender __P ((int msgno, int strip));
 extern void util_slist_print __P ((list_t list, int nl));
 extern int util_slist_lookup __P ((list_t list, char *str));
 extern void util_slist_add __P ((list_t *list, char *value));
+extern void util_slist_remove __P((list_t *list, char *value));
 extern void util_slist_destroy __P ((list_t *list));
 extern char *util_slist_to_string __P ((list_t list, const char *delim));
 extern void util_strcat __P ((char **dest, const char *str));
@@ -296,6 +308,7 @@ extern char *util_outfolder_name __P ((char *str));
 extern void util_save_outgoing __P ((message_t msg, char *savefile));
 extern void util_error __P ((const char *format, ...));
 extern int util_error_range __P ((size_t msgno));
+extern void util_noapp __P ((void));
 extern int util_help __P ((const struct mail_command_entry *table, char *word));
 extern int util_tempfile __P ((char **namep));
 extern void util_msgset_iterate __P ((msgset_t *msgset, int (*fun) __P ((message_t, msgset_t *, void *)), void *closure));
@@ -304,13 +317,18 @@ extern int util_get_hdr_value __P ((header_t hdr, const char *name, char **value
 extern int util_merge_addresses __P((char **addr_str, const char *value));
 extern int util_header_expand __P((header_t *hdr));
 extern int util_get_message __P((mailbox_t mbox, size_t msgno,
-				 message_t *msg, int flag));
+				 message_t *msg));
+void util_cache_command __P((list_t *list, const char *fmt, ...));
+void util_run_cached_commands __P((list_t *list));
+const char *util_reply_prefix __P((void));
+void util_rfc2047_decode __P((char **value));
 
 extern int ml_got_interrupt __P ((void));
 extern void ml_clear_interrupt __P ((void));
 extern void ml_readline_init __P ((void));
 extern int ml_reread __P ((const char *prompt, char **text));
-extern char *ml_readline __P((const char *prompt));
+extern char *ml_readline __P((char *prompt));
+extern char *ml_readline_with_intr __P((char *prompt));
 
 extern char *alias_expand __P ((char *name));
 extern void alias_destroy __P ((char *name));
@@ -327,7 +345,7 @@ char *compose_header_get __P((compose_env_t *env, char *name,
 void compose_destroy __P((compose_env_t *env));
 
 #ifndef HAVE_READLINE_READLINE_H
-extern char *readline __P ((const char *prompt));
+extern char *readline __P ((char *prompt));
 #endif
 
 #ifndef _PATH_SENDMAIL
