@@ -1,19 +1,19 @@
-/* GNU mailutils - a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001, 2002 Free Software Foundation, Inc.
+/* GNU Mailutils -- a suite of utilities for electronic mail
+   Copyright (C) 1999, 2001, 2002, 2003 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, or (at your option)
    any later version.
 
-   This program is distributed in the hope that it will be useful,
+   GNU Mailutils is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   along with GNU Mailutils; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
 
 #include "mail.h"
 
@@ -33,27 +33,37 @@ mail_next (int argc, char **argv)
       int rc = 1;
       for (n = cursor + 1; n <= total; n++)
 	{
-	  rc = util_get_message (mbox, n, &msg, MSG_NODELETED|MSG_SILENT);
+	  if (util_isdeleted (n))
+	    continue;
+	  rc = util_get_message (mbox, n, &msg);
 	  if (rc == 0)
 	    break;
 	}
 
       if (rc)
 	{
-	  util_error ("No applicable message");
+	  util_error (_("No applicable message"));
 	  return 1;
 	}
     }
   else
     {
       msgset_t *list = NULL;
-      msgset_parse (argc, argv, &list);
-      n = list->msg_part[0];
-      msgset_free (list);
-      if (util_get_message (mbox, n, &msg, MSG_NODELETED|MSG_SILENT))
-	return 1;
+      int rc = msgset_parse (argc, argv, MSG_NODELETED|MSG_SILENT, &list);
+      if (!rc)
+	{
+	  n = list->msg_part[0];
+	  msgset_free (list);
+	  if (util_get_message (mbox, n, &msg))
+	    return 1;
+	}
+      else
+	{
+	  util_error (_("No applicable message"));
+	  return 1;
+	}
     }
-  cursor = realcursor = n;
+  cursor = n;
   util_do_command("print");
   return 0;
 }
