@@ -51,6 +51,7 @@ const struct mail_command_entry mail_command_table[] = {
   { "m",	"mail",		"m[ail] [address...]",		EF_SEND, mail_send, 0 },
   { "mb",	"mbox",		"mb[ox] [msglist]",		0, mail_mbox, 0 },
   { "n",	"next",		"n[ext] [message]",		0, mail_next, 0 },
+  { "nou",      "nounfold",     "nou[nfold] [header-field]",    0, mail_nounfold, 0 },
   { "P",	"Print",	"P[rint] [msglist]",		0, mail_print, 0 },
   { "pi",	"pipe",		"pi[pe] [[msglist] command]",	0, mail_pipe, 0 },
   { "pre",	"preserve",	"pre[serve] [msglist]",		0, mail_hold, 0 },
@@ -78,6 +79,7 @@ const struct mail_command_entry mail_command_table[] = {
   { "t",	"type",		"t[ype] [msglist]",		0, mail_print, 0 },
   { "una",	"unalias",	"una[lias] [alias]...",		0, mail_unalias, 0 },
   { "u",	"undelete",	"u[ndelete] [msglist]",		0, mail_undelete, 0 },
+  { "unf",      "unfold",       "unf[old] [header-field]",      0, mail_unfold, 0 },
   { "uns",	"unset",	"uns[et] name...",		0, mail_unset, 0 },
   { "unt",      "untag",	"unt[ag] [msglist]",		0, mail_tag, 0 },
   { "ve",	"version",	"ve[rsion]",			0, mail_version, 0 },
