@@ -30,9 +30,10 @@ extern "C" {
 
 struct _iterator
 {
-  list_t list;
-  size_t index;
-
+  struct _iterator *next;   /* Next iterator in the chain */
+  list_t list;              /* Owner list */
+  struct list_data *cur;    /* Current list item */
+  int is_advanced;          /* Is the item already advanced */   
 };
 
 
@@ -40,4 +41,6 @@ struct _iterator
 }
 #endif
 
+extern void iterator_advance(iterator_t iterator, struct list_data *e);
+
 #endif /* _ITERATOR0_H */
