@@ -1,19 +1,19 @@
-/* GNU mailutils - a suite of utilities for electronic mail
+/* GNU Mailutils -- a suite of utilities for electronic mail
    Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Library Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   This library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Lesser General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
 
-   This program is distributed in the hope that it will be useful,
+   This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU Library General Public License for more details.
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Library General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   You should have received a copy of the GNU Lesser General Public
+   License along with this library; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -109,23 +109,15 @@ mailbox_create (mailbox_t *pmbox, const char *name)
 
       /* Create the folder before initializing the concrete mailbox.
 	 The mailbox needs it's back pointer. */
-      {
-	folder_t folder;
-	if (folder_create (&folder, name) == 0)
-	  mbox->folder = folder;
-      }
+      status = folder_create (&mbox->folder, name);
+
+      if (status == 0)
+	status = m_init (mbox);   /* Create the concrete mailbox type.  */
 
-      /* Create the concrete mailbox type.  */
-      status = m_init (mbox);
       if (status != 0)
-	{
-	  mailbox_destroy (&mbox);
-	}
+	mailbox_destroy (&mbox);
       else
-	{
-	  *pmbox = mbox;
-	}
-
+	*pmbox = mbox;
     }
   else
     status = MU_ERR_NO_HANDLER;
@@ -211,6 +203,8 @@ mailbox_flush (mailbox_t mbox, int expunge)
   size_t i, total = 0;
   int status = 0;
 
+  if (!mbox)
+    return EINVAL;
   if (!(mbox->flags & (MU_STREAM_RDWR|MU_STREAM_WRITE|MU_STREAM_APPEND)))
     return EACCES;
   mailbox_messages_count (mbox, &total);
