@@ -82,9 +82,9 @@ mu_auth_data_alloc (struct mu_auth_data **ptr,
   p = (char *)(*ptr + 1);
   
 #define COPY(f) \
-  (*ptr)->##f = p; \
-  strcpy (p, ##f); \
-  p += strlen (##f) + 1
+  (*ptr)->f = p; \
+  strcpy (p, f); \
+  p += strlen (f) + 1
   
   COPY (name);
   COPY (passwd);
@@ -121,7 +121,8 @@ mu_insert_stack_entry (list_t *pflist, struct auth_stack_entry *entry)
 }
 
 int
-mu_auth_runlist (list_t flist, void *return_data, void *key, void *data)
+mu_auth_runlist (list_t flist, struct mu_auth_data **return_data,
+		 void *key, void *data)
 {
   int rc = 1;
   iterator_t itr;
@@ -145,8 +146,10 @@ mu_auth_runlist (list_t flist, void *return_data, void *key, void *data)
 }
 
 int
-mu_auth_nosupport (void *usused_return_data, void *unused_key,
-		   void *unused_func_data, void *unused_call_data)
+mu_auth_nosupport (struct mu_auth_data **return_data ARG_UNUSED,
+		   void *key ARG_UNUSED,
+		   void *func_data ARG_UNUSED,
+		   void *call_data ARG_UNUSED)
 {
   errno = ENOSYS;
   return 1;
@@ -273,7 +276,7 @@ mu_auth_register_module (struct mu_auth_module *mod)
 	  for (i = 0; mu_auth_argp.children[i].argp; i++)
 	    ;
 	  tmp = realloc ((void*) mu_auth_argp.children,
-			 (i+1) * sizeof(mu_auth_argp.children[0]));
+			 (i + 2) * sizeof(mu_auth_argp.children[0]));
 	  mu_auth_argp.children = tmp;
 	}
       else
