@@ -239,12 +239,20 @@ mh_check_folder (char *pathname, int confirm)
 }
 
 int
-mh_getyn (const char *fmt, ...)
+mh_interactive_mode_p ()
+{
+  static int interactive = -1;
+
+  if (interactive < 0)
+    interactive = isatty (fileno (stdin)) ? 1 : 0;
+  return interactive;
+}
+
+int
+mh_vgetyn (const char *fmt, va_list ap)
 {
-  va_list ap;
   char repl[64];
-  
-  va_start (ap, fmt);
+
   while (1)
     {
       char *p;
@@ -277,6 +285,32 @@ mh_getyn (const char *fmt, ...)
   return 0; /* to pacify gcc */
 }
 
+int
+mh_getyn (const char *fmt, ...)
+{
+  va_list ap;
+  int rc;
+  
+  if (!mh_interactive_mode_p ())
+      return 1;
+  va_start (ap, fmt);
+  rc = mh_vgetyn (fmt, ap);
+  va_end (ap);
+  return rc;
+}
+
+int
+mh_getyn_interactive (const char *fmt, ...)
+{
+  va_list ap;
+  int rc;
+  
+  va_start (ap, fmt);
+  rc = mh_vgetyn (fmt, ap);
+  va_end (ap);
+  return rc;
+}
+	    
 FILE *
 mh_audit_open (char *name, mailbox_t mbox)
 {
@@ -606,15 +640,15 @@ mh_real_install (char *name, int automode)
     {
       size_t n = 0;
       
-      if (mh_getyn (_("Do you need help")))
+      if (mh_getyn_interactive (_("Do you need help")))
 	mh_install_help (mhdir);
 
-      if (!mh_getyn (_("Do you want the standard MH path \"%s\""), mhdir))
+      if (!mh_getyn_interactive (_("Do you want the standard MH path \"%s\""), mhdir))
 	{
 	  int local;
 	  char *p;
 	  
-	  local = mh_getyn (_("Do you want a path below your login directory"));
+	  local = mh_getyn_interactive (_("Do you want a path below your login directory"));
 	  if (local)
 	    printf (_("What is the path? "));
 	  else
@@ -761,3 +795,14 @@ mh_create_message_id (int subpart)
   free (host);
   return p;
 }
+
+void
+mh_set_reply_regex (const char *str)
+{
+  char *err;
+  int rc = munre_set_regex (str, 0, &err);
+  if (rc)
+    mh_error ("reply_regex: %s%s%s", mu_strerror (rc),
+	      err ? ": " : "",
+	      err ? err : "");
+}
