@@ -19,7 +19,7 @@
 
 #include <mh.h>
 
-const char *argp_program_version = "mhpath (" PACKAGE_STRING ")";
+const char *program_version = "mhpath (" PACKAGE_STRING ")";
 static char doc[] = N_("GNU MH mhpath\v"
 "Use -help to obtain the list of traditional MH options.");
 static char args_doc[] = N_("[+folder] [msgs]");
@@ -28,6 +28,8 @@ static char args_doc[] = N_("[+folder] [msgs]");
 static struct argp_option options[] = {
   {"folder",  ARG_FOLDER, N_("FOLDER"), 0,
    N_("Specify folder to operate upon")},
+  {"license", ARG_LICENSE, 0,      0,
+   N_("Display software license"), -1},
   { 0 }
 };
 
@@ -41,11 +43,14 @@ opt_handler (int key, char *arg, void *unused, struct argp_state *state)
 {
   switch (key)
     {
-    case '+':
     case ARG_FOLDER:
       current_folder = arg;
       break;
       
+    case ARG_LICENSE:
+      mh_license (argp_program_version);
+      break;
+
     default:
       return 1;
     }
@@ -75,6 +80,7 @@ main (int argc, char **argv)
   /* Native Language Support */
   mu_init_nls ();
 
+  mu_argp_init (program_version, NULL);
   mh_argp_parse (argc, argv, 0, options, mh_option, args_doc, doc,
 		 opt_handler, NULL, &index);
 
