@@ -21,7 +21,7 @@
 #include <sys/stat.h>
 #include <unistd.h>
 
-const char *argp_program_version = "reply (" PACKAGE_STRING ")";
+const char *program_version = "reply (" PACKAGE_STRING ")";
 static char doc[] = N_("GNU MH repl\v"
 "Options marked with `*' are not yet implemented.\n"
 "Use -help to obtain the list of traditional MH options.");
@@ -45,22 +45,28 @@ static struct argp_option options[] = {
   {"nocc", ARG_NOCC, "{all|to|cc|me}", 0,
    N_("Specify whom to remove from the Cc: list of the reply")},
   {"folder",  ARG_FOLDER, N_("FOLDER"), 0, N_("Specify folder to operate upon")},
+  {"group",  ARG_GROUP,  N_("BOOL"), OPTION_ARG_OPTIONAL,
+   N_("Construct a group or followup reply") },
   {"editor", ARG_EDITOR, N_("PROG"), 0, N_("Set the editor program to use")},
   {"noedit", ARG_NOEDIT, 0, 0, N_("Suppress the initial edit")},
   {"fcc",    ARG_FCC, N_("FOLDER"), 0, N_("* Set the folder to receive Fcc's.")},
   {"filter", ARG_FILTER, N_("MHL-FILTER"), 0,
    N_("Set the mhl filter to preprocess the body of the message being replied")},
   {"form",   ARG_FORM, N_("FILE"), 0, N_("Read format from given file")},
+  {"format", ARG_FORMAT, N_("BOOL"), OPTION_ARG_OPTIONAL,
+   N_("Include a copy of the message being replied. The message will be processed using either the default filter \"mhl.reply\", or the filter specified by --filter option.") },
   {"inplace", ARG_INPLACE, N_("BOOL"), OPTION_ARG_OPTIONAL,
    N_("* Annotate the message in place")},
   {"query", ARG_QUERY, N_("BOOL"), OPTION_ARG_OPTIONAL,
-   N_("* Query for addresses to place in To: and Cc: lists")},
+   N_("Query for addresses to place in To: and Cc: lists")},
   {"width", ARG_WIDTH, N_("NUMBER"), 0, N_("Set output width")},
   {"whatnowproc", ARG_WHATNOWPROC, N_("PROG"), 0,
    N_("* Set the replacement for whatnow program")},
   {"nowhatnowproc", ARG_NOWHATNOWPROC, NULL, 0,
    N_("* Ignore whatnowproc variable. Use standard `whatnow' shell instead.")},
   {"use", ARG_USE, N_("BOOL"), OPTION_ARG_OPTIONAL, N_("Use draft file preserved after the last session") },
+  {"license", ARG_LICENSE, 0,      0,
+   N_("Display software license"), -1},
   { 0 }
 };
 
@@ -79,6 +85,8 @@ struct mh_option mh_option[] = {
   {"noedit",      3, },
   {"fcc",         1, MH_OPT_ARG, "folder"},
   {"filter",      2, MH_OPT_ARG, "program"},
+  {"format",      2, MH_OPT_BOOL },
+  {"group",       1, MH_OPT_BOOL },
   {"inplace",     1, MH_OPT_BOOL },
   {"query",       1, MH_OPT_BOOL },
   {"whatnowproc", 2, MH_OPT_ARG, "program"},
@@ -86,7 +94,7 @@ struct mh_option mh_option[] = {
   { 0 }
 };
 
-static char *format_str =
+static char default_format_str[] =
 "%(lit)%(formataddr %<{reply-to}%?{from}%?{sender}%?{return-path}%>)"
 "%<(nonnull)%(void(width))%(putaddr To: )\\n%>"
 "%(lit)%<(rcpt to)%(formataddr{to})%>%<(rcpt cc)%(formataddr{cc})%>%<(rcpt me)%(formataddr(me))%>"
@@ -98,6 +106,7 @@ static char *format_str =
 "X-Mailer: MH \\(%(package_string)\\)\\n" 
 "--------\n";
 
+static char *format_str = NULL;
 static mh_format_t format;
 static int width = 80;
 
@@ -149,17 +158,33 @@ opt_handler (int key, char *arg, void *unused, struct argp_state *state)
       wh_env.editor = arg;
       break;
       
-    case '+':
     case ARG_FOLDER: 
       current_folder = arg;
       break;
 
     case ARG_FORM:
+      free (format_str);
+      format_str = NULL;
       s = mh_expand_name (MHLIBDIR, arg, 0);
       mh_read_formfile (s, &format_str);
       free (s);
       break;
 
+    case ARG_GROUP:
+      if (is_true (arg))
+	{
+	  s = mh_expand_name (MHLIBDIR, "replgroupcomps", 0);
+	  mh_read_formfile (s, &format_str);
+	  free (s);
+	  rcpt_mask |= RCPT_ALL;
+	}
+      else
+	{
+	  free (format_str);
+	  format_str = NULL;
+	}
+      break;
+	    
     case ARG_DRAFTMESSAGE:
       wh_env.draftmessage = arg;
       break;
@@ -192,6 +217,16 @@ opt_handler (int key, char *arg, void *unused, struct argp_state *state)
     case ARG_FILTER:
       mhl_filter = arg;
       break;
+
+    case ARG_FORMAT:
+      if (is_true (arg))
+	{
+	  if (!mhl_filter)
+	    mhl_filter = mh_expand_name (MHLIBDIR, "mhl.repl", 0);
+	}
+      else
+	mhl_filter = NULL;
+      break;
       
     case ARG_ANNOTATE:
     case ARG_FCC:
@@ -201,6 +236,15 @@ opt_handler (int key, char *arg, void *unused, struct argp_state *state)
       argp_error (state, _("option is not yet implemented"));
       exit (1);
       
+    case ARG_LICENSE:
+      mh_license (argp_program_version);
+      break;
+
+    case ARGP_KEY_FINI:
+      if (!format_str)
+	format_str = default_format_str;
+      break;
+      
     default:
       return 1;
     }
@@ -283,7 +327,7 @@ make_draft (mailbox_t mbox, int disp, struct mh_whatnow_env *wh)
 	  list_t filter = mhl_format_compile (mhl_filter);
 	  if (!filter)
 	    exit (1);
-	  mhl_format_run (filter, width, 0, 0, 0, msg, str);
+	  mhl_format_run (filter, width, 0, 0, msg, str);
 	  mhl_format_destroy (&filter);
 	}
 
@@ -318,6 +362,7 @@ main (int argc, char **argv)
   /* Native Language Support */
   mu_init_nls ();
 
+  mu_argp_init (program_version, NULL);
   mh_argp_parse (argc, argv, 0, options, mh_option, args_doc, doc,
 		 opt_handler, NULL, &index);
   if (mh_format_parse (format_str, &format))
